#include "contactsjsoncontroller.h"
#include <QVariant>

#define F_CITY "city"
#define F_STREET "street"
#define F_NUMBER "number"
#define F_NAME "name"
#define F_BIRTH_DATE "birthDate"
#define F_ADDRESSES "addresses"

ContactsJsonController::ContactsJsonController()
{

}

QByteArray ContactsJsonController::list()
{
    //Создание и заполнение json-массива json-объектами, сформированными объектами Contact
    QJsonArray jContacts;
    foreach (Contact contact, _items) {
        jContacts.append(contact.toJsonObject());
    }
    return QJsonDocument(jContacts).toJson();
}

void ContactsJsonController::append(QByteArray json)
{
    //Корневым значением документа является json-объект
    QJsonObject jContact = QJsonDocument::fromJson(json).object();
    _items.append(Contact(jContact));
}

void ContactsJsonController::clear()
{
    _items.clear();
}

Address::Address(QJsonObject jObj)
{
    //Чтение простых значений полей объекта
    _city = jObj.value(F_CITY).toString();
    _street = jObj.value(F_STREET).toString();
    _number = jObj.value(F_NUMBER).toInt();
}

QJsonObject Address::toJsonObject()
{
    //Создание и заполнение json-объекта простыми значениями
    QJsonObject jObj;    
    jObj.insert(F_CITY, QJsonValue::fromVariant(_city));
    jObj.insert(F_STREET, QJsonValue::fromVariant(_street));
    jObj.insert(F_NUMBER, QJsonValue::fromVariant(_number));
    return jObj;
}

Contact::Contact(QJsonObject jObj)
{
    _name = jObj.value(F_NAME).toString();
    //Чтение простых значений, для которых нет специальных методов преобразование QJsonValue
    _birthDate = jObj.value(F_BIRTH_DATE).toVariant().toDate();
    //Чтение элементов json-массива, имеющего ключ addresses
    QJsonArray jAddresses = jObj.value(F_ADDRESSES).toArray();
    foreach (QJsonValue jVal, jAddresses) {
        QJsonObject jAddr = jVal.toObject();
        _addresses.append(Address(jAddr));
    }
}

QJsonObject Contact::toJsonObject()
{
    QJsonObject jObj;
    jObj.insert(F_NAME, QJsonValue::fromVariant(_name));
    jObj.insert(F_BIRTH_DATE, QJsonValue::fromVariant(_birthDate));
    //Создание и заполнение json-массива
    QJsonArray jAddrArr;
    foreach (Address addr, _addresses) {
        jAddrArr.append(addr.toJsonObject());
    }
    //Добавление json-массива в json-объект с ключом addresses
    jObj.insert(F_ADDRESSES, jAddrArr);
    return jObj;
}






